/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.44 from the
 * contents of XRC.xs. Do not edit this file, edit XRC.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

/////////////////////////////////////////////////////////////////////////////
// Name:        ext/xrc/XRC.xs
// Purpose:     XS for wxWidgets XML Resources
// Author:      Mattia Barbon
// Modified by:
// Created:     27/07/2001
// RCS-ID:      $Id: XRC.xs 2757 2010-01-17 10:26:27Z mbarbon $
// Copyright:   (c) 2001-2004, 2006, 2008-2010 Mattia Barbon
// Licence:     This program is free software; you can redistribute it and/or
//              modify it under the same terms as Perl itself
/////////////////////////////////////////////////////////////////////////////

#define PERL_NO_GET_CONTEXT

#include "cpp/wxapi.h"
#include "cpp/xr_constants.cpp"

#undef THIS

#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif


/* INCLUDE:  Including 'XS/XmlResource.xs' from 'XRC.xs' */

#include <wx/xrc/xmlres.h>
#include <wx/menu.h>
#include <wx/dialog.h>
#include <wx/panel.h>
#include <wx/toolbar.h>
#include <wx/frame.h>
#include "cpp/overload.h"
#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_Wx__XmlResource_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "CLASS, flags = wxXRC_USE_LOCALE, domain = wxEmptyString");
    {
	int	flags;
	wxString	domain;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxXmlResource *	RETVAL;

	if (items < 2)
	    flags = wxXRC_USE_LOCALE;
	else {
	    flags = (int)SvIV(ST(1))
;
	}

	if (items < 3)
	    domain = wxEmptyString;
	else {
    WXSTRING_INPUT( domain, wxString, ST(2) )
;
	}

	RETVAL = new wxXmlResource(flags, domain);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlResource" );
    wxPli_thread_sv_register( aTHX_ "Wx::XmlResource", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_Wx__XmlResource_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "CLASS, flags = wxXRC_USE_LOCALE");
    {
	int	flags;
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxXmlResource *	RETVAL;

	if (items < 2)
	    flags = wxXRC_USE_LOCALE;
	else {
	    flags = (int)SvIV(ST(1))
;
	}

	RETVAL = new wxXmlResource(flags);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlResource" );
    wxPli_thread_sv_register( aTHX_ "Wx::XmlResource", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__XmlResource_CLONE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_CLONE)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
    wxPli_thread_sv_clone( aTHX_ CLASS, (wxPliCloneSV)wxPli_detach_object );
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResource_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
    wxPli_thread_sv_unregister( aTHX_ "Wx::XmlResource", THIS, ST(0) );
    delete THIS;
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResource_Load); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_Load)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filemask");
    {
	wxString	filemask;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	bool	RETVAL;

    WXSTRING_INPUT( filemask, wxString, ST(1) )
;

	RETVAL = THIS->Load(filemask);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 6, 3 )
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_Wx__XmlResource_Unload); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_Unload)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, filemask");
    {
	wxString	filemask;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	bool	RETVAL;

    WXSTRING_INPUT( filemask, wxString, ST(1) )
;

	RETVAL = THIS->Unload(filemask);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__XmlResource_InitAllHandlers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_InitAllHandlers)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;

	THIS->InitAllHandlers();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResource_AddHandler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_AddHandler)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, handler");
    {
	wxXmlResourceHandler*    handler = (wxXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlResourceHandler" )
;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;

	THIS->AddHandler(handler);
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResource_ClearHandlers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_ClearHandlers)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;

	THIS->ClearHandlers();
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResource_LoadMenu); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadMenu)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxMenu *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	RETVAL = THIS->LoadMenu(name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadMenuBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadMenuBar)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxMenuBar *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	RETVAL = THIS->LoadMenuBar(name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadMenuBarOnParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadMenuBarOnParent)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, name");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxMenuBar *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(2) )
;
    RETVAL = THIS->LoadMenuBar( parent, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadToolBar); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadToolBar)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, name");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxToolBar *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(2) )
;

	RETVAL = THIS->LoadToolBar(parent, name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_evthandler_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadDialog)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, name");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxDialog *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(2) )
;

	RETVAL = THIS->LoadDialog(parent, name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadOnDialog); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadOnDialog)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, dialog, parent, name");
    {
	wxDialog*    dialog = (wxDialog *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Dialog" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	bool	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(3) )
;
    RETVAL = THIS->LoadDialog( dialog, parent, name );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadPanel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadPanel)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, name");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxPanel *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(2) )
;

	RETVAL = THIS->LoadPanel(parent, name);
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadOnPanel); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadOnPanel)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, panel, parent, name");
    {
	wxPanel*    panel = (wxPanel *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Panel" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	bool	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(3) )
;
    RETVAL = THIS->LoadPanel( panel, parent, name );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadFrame); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadFrame)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "THIS, ...");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
    BEGIN_OVERLOAD()
        MATCH_REDISP( wxPliOvl_wfrm_wwin_s, LoadOnFrame )
        MATCH_REDISP( wxPliOvl_wwin_s, LoadFrame2 )
    END_OVERLOAD( "Wx::XmlResource::LoadFrame" )
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_Wx__XmlResource_LoadFrame2); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadFrame2)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, parent, name");
    {
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxFrame *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(2) )
;
    RETVAL = THIS->LoadFrame( parent, name );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadOnFrame); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadOnFrame)
{
    dVAR; dXSARGS;
    if (items != 4)
       croak_xs_usage(cv,  "THIS, frame, parent, name");
    {
	wxFrame*    frame = (wxFrame *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Frame" )
;
	wxWindow*    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	bool	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(3) )
;
    RETVAL = THIS->LoadFrame( frame, parent, name );
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadBitmap)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxBitmap *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    RETVAL = new wxBitmap( THIS->LoadBitmap( name ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_LoadIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_LoadIcon)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxString	name;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	wxIcon *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    RETVAL = new wxIcon( THIS->LoadIcon( name ) );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_AttachUnknownControl); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_AttachUnknownControl)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, name, control, parent = 0");
    {
	wxString	name;
	wxWindow*    control = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Window" )
;
	wxWindow*	parent;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	bool	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	if (items < 4)
	    parent = 0;
	else {
    parent = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Window" )
;
	}

	RETVAL = THIS->AttachUnknownControl(name, control, parent);
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_GetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_GetFlags)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetFlags();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_SetFlags); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_SetFlags)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, flags");
    {
	int	flags = (int)SvIV(ST(1))
;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;

	THIS->SetFlags(flags);
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 2 )
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_Wx__XmlResource_GetXRCID); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_GetXRCID)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "str_id, value_if_not_found = wxID_NONE");
    {
	wxChar*	str_id;
	int	value_if_not_found;
	int	RETVAL;
	dXSTARG;

    WXCHAR_INPUT( str_id, wxChar*, ST(0) )
;

	if (items < 2)
	    value_if_not_found = wxID_NONE;
	else {
	    value_if_not_found = (int)SvIV(ST(1))
;
	}
    RETVAL = wxXmlResource::GetXRCID( str_id, value_if_not_found );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_Wx__XmlResource_GetXRCID); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_GetXRCID)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "str_id");
    {
	wxChar*	str_id;
	int	RETVAL;
	dXSTARG;

    WXCHAR_INPUT( str_id, wxChar*, ST(0) )
;
    RETVAL = wxXmlResource::GetXRCID( str_id );
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__XmlResource_GetVersion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_GetVersion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	long	RETVAL;
	dXSTARG;

	RETVAL = THIS->GetVersion();
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_CompareVersion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_CompareVersion)
{
    dVAR; dXSARGS;
    if (items != 5)
       croak_xs_usage(cv,  "THIS, major, minor, release, revision");
    {
	int	major = (int)SvIV(ST(1))
;
	int	minor = (int)SvIV(ST(2))
;
	int	release = (int)SvIV(ST(3))
;
	int	revision = (int)SvIV(ST(4))
;
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	int	RETVAL;
	dXSTARG;

	RETVAL = THIS->CompareVersion(major, minor, release, revision);
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_AddSubclassFactory); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_AddSubclassFactory)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "factory");
    {
	wxXmlSubclassFactory *    factory = (wxXmlSubclassFactory *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlSubclassFactory" )
;
    wxPli_detach_object( aTHX_ ST(0) ); // avoid destructor
    wxXmlResource::AddSubclassFactory( factory );
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 7, 1 )
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_Wx__XmlResource_GetDomain); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_GetDomain)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	const wxChar *	RETVAL;

	RETVAL = THIS->GetDomain();
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXCHAR_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResource_SetDomain); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResource_SetDomain)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, domain");
    {
	wxXmlResource *    THIS = (wxXmlResource *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlResource" )
;
	const wxChar*	domain;

    WXCHAR_INPUT( domain, wxChar*, ST(1) )
;

	THIS->SetDomain(domain);
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XRC.xs' from 'XS/XmlResource.xs' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/XmlSubclassFactory.xsp' from 'XRC.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include "xspp/factory.h"
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)

XS_EUPXS(XS_Wx__XmlSubclassFactory_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlSubclassFactory_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxXmlSubclassFactory *	RETVAL;
     RETVAL = new wxPliXmlSubclassFactory( CLASS ); 
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlSubclassFactory" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

/* INCLUDE: Returning to 'XRC.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/XmlSubclassFactory.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/XmlDocument.xsp' from 'XRC.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__XmlDocument_IsOk); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_IsOk)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	bool	RETVAL;
    try {
      RETVAL = THIS->IsOk();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlDocument_GetRoot); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_GetRoot)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	wxXmlNode *	RETVAL;
    try {
      RETVAL = THIS->GetRoot();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlNode" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlDocument_GetVersion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_GetVersion)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetVersion();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlDocument_GetFileEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_GetFileEncoding)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetFileEncoding();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlDocument_SetRoot); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_SetRoot)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, node");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	wxXmlNode*    node = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
    try {
      THIS->SetRoot( node );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlDocument_SetVersion); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_SetVersion)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, version");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	wxString	version;

    WXSTRING_INPUT( version, wxString, ST(1) )
;
    try {
      THIS->SetVersion( version );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlDocument_SetFileEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_SetFileEncoding)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, encoding");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	wxString	encoding;

    WXSTRING_INPUT( encoding, wxString, ST(1) )
;
    try {
      THIS->SetFileEncoding( encoding );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if !wxUSE_UNICODE
#define XSpp_adb7c945_058581
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_Wx__XmlDocument_GetEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_GetEncoding)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetEncoding();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlDocument_SetEncoding); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlDocument_SetEncoding)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, enc");
    {
	wxXmlDocument *    THIS = (wxXmlDocument *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlDocument" )
;
	wxString	enc;

    WXSTRING_INPUT( enc, wxString, ST(1) )
;
    try {
      THIS->SetEncoding( enc );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

/* INCLUDE: Returning to 'XRC.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/XmlDocument.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/XmlNode.xsp' from 'XRC.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_269e5187_087451
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_Wx__XmlAttribute_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlAttribute_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "CLASS, name= wxEmptyString, value= wxEmptyString, next= NULL");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxXmlAttribute *	RETVAL;
	wxString	name;
	wxString	value;
	wxXmlAttribute*	next;

	if (items < 2)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}

	if (items < 3)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(2) )
;
	}

	if (items < 4)
	    next = NULL;
	else {
    next = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::XmlAttribute" )
;
	}
    try {
      RETVAL = new wxXmlAttribute( name, value, next );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlAttribute" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__XmlAttribute_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlAttribute_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlAttribute *    THIS = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlAttribute" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlAttribute_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlAttribute_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlAttribute *    THIS = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlAttribute" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetValue();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlAttribute_GetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlAttribute_GetNext)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlAttribute *    THIS = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlAttribute" )
;
	wxXmlAttribute *	RETVAL;
    try {
      RETVAL = THIS->GetNext();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlAttribute" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlAttribute_SetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlAttribute_SetName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxXmlAttribute *    THIS = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlAttribute" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlAttribute_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlAttribute_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxXmlAttribute *    THIS = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlAttribute" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlAttribute_SetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlAttribute_SetNext)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, next");
    {
	wxXmlAttribute *    THIS = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlAttribute" )
;
	wxXmlAttribute*    next = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlAttribute" )
;
    try {
      THIS->SetNext( next );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlAttribute_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlAttribute_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlAttribute *    THIS = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlAttribute" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}

#else
#define XSpp_269e5187_002354
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_Wx__XmlProperty_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlProperty_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "CLASS, name= wxEmptyString, value= wxEmptyString, next= NULL");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxXmlProperty *	RETVAL;
	wxString	name;
	wxString	value;
	wxXmlProperty*	next;

	if (items < 2)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(1) )
;
	}

	if (items < 3)
	    value = wxEmptyString;
	else {
    WXSTRING_INPUT( value, wxString, ST(2) )
;
	}

	if (items < 4)
	    next = NULL;
	else {
    next = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::XmlProperty" )
;
	}
    try {
      RETVAL = new wxXmlProperty( name, value, next );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlProperty" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)

XS_EUPXS(XS_Wx__XmlProperty_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlProperty_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlProperty *    THIS = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlProperty" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlProperty_GetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlProperty_GetValue)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlProperty *    THIS = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlProperty" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetValue();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlProperty_GetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlProperty_GetNext)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlProperty *    THIS = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlProperty" )
;
	wxXmlProperty *	RETVAL;
    try {
      RETVAL = THIS->GetNext();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlProperty" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlProperty_SetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlProperty_SetName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxXmlProperty *    THIS = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlProperty" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlProperty_SetValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlProperty_SetValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, value");
    {
	wxXmlProperty *    THIS = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlProperty" )
;
	wxString	value;

    WXSTRING_INPUT( value, wxString, ST(1) )
;
    try {
      THIS->SetValue( value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlProperty_SetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlProperty_SetNext)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, next");
    {
	wxXmlProperty *    THIS = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlProperty" )
;
	wxXmlProperty*    next = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlProperty" )
;
    try {
      THIS->SetNext( next );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlProperty_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlProperty_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlProperty *    THIS = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlProperty" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_269e5187_037591
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_Wx__XmlNode_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent= NULL, type= wxXmlNodeType(0), name= wxEmptyString, content= wxEmptyString, props= NULL, next= NULL");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxXmlNode *	RETVAL;
	wxXmlNode*	parent;
	wxXmlNodeType	type;
	wxString	name;
	wxString	content;
	wxXmlAttribute*	props;
	wxXmlNode*	next;

	if (items < 2)
	    parent = NULL;
	else {
    parent = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
	}

	if (items < 3)
	    type = wxXmlNodeType(0);
	else {
	    type = (wxXmlNodeType)SvIV(ST(2))
;
	}

	if (items < 4)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(3) )
;
	}

	if (items < 5)
	    content = wxEmptyString;
	else {
    WXSTRING_INPUT( content, wxString, ST(4) )
;
	}

	if (items < 6)
	    props = NULL;
	else {
    props = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(5), "Wx::XmlAttribute" )
;
	}

	if (items < 7)
	    next = NULL;
	else {
    next = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::XmlNode" )
;
	}
    try {
      RETVAL = new wxXmlNode( parent, type, name, content, props, next );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlNode" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#else
#define XSpp_269e5187_024042
#undef  xsp_constructor_class
#define xsp_constructor_class(c) (CLASS)
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_Wx__XmlNode_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_new)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 7)
       croak_xs_usage(cv,  "CLASS, parent= NULL, type= wxXmlNodeType(0), name= wxEmptyString, content= wxEmptyString, props= NULL, next= NULL");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxXmlNode *	RETVAL;
	wxXmlNode*	parent;
	wxXmlNodeType	type;
	wxString	name;
	wxString	content;
	wxXmlProperty*	props;
	wxXmlNode*	next;

	if (items < 2)
	    parent = NULL;
	else {
    parent = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
	}

	if (items < 3)
	    type = wxXmlNodeType(0);
	else {
	    type = (wxXmlNodeType)SvIV(ST(2))
;
	}

	if (items < 4)
	    name = wxEmptyString;
	else {
    WXSTRING_INPUT( name, wxString, ST(3) )
;
	}

	if (items < 5)
	    content = wxEmptyString;
	else {
    WXSTRING_INPUT( content, wxString, ST(4) )
;
	}

	if (items < 6)
	    props = NULL;
	else {
    props = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(5), "Wx::XmlProperty" )
;
	}

	if (items < 7)
	    next = NULL;
	else {
    next = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(6), "Wx::XmlNode" )
;
	}
    try {
      RETVAL = new wxXmlNode( parent, type, name, content, props, next );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlNode" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#endif

XS_EUPXS(XS_Wx__XmlNode_AddChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_AddChild)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, child");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNode*    child = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
    try {
      THIS->AddChild( child );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_InsertChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_InsertChild)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, child, before_node");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNode*    child = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
	wxXmlNode*    before_node = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::XmlNode" )
;
    try {
      THIS->InsertChild( child, before_node );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_RemoveChild); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_RemoveChild)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, child");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	bool	RETVAL;
	wxXmlNode*    child = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
    try {
      RETVAL = THIS->RemoveChild( child );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_269e5187_084381
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_Wx__XmlNode_AddAttribute); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_AddAttribute)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, name, value");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxString	name;
	wxString	value;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

    WXSTRING_INPUT( value, wxString, ST(2) )
;
    try {
      THIS->AddAttribute( name, value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_DeleteAttribute); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_DeleteAttribute)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	bool	RETVAL;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      RETVAL = THIS->DeleteAttribute( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_269e5187_058843
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_Wx__XmlNode_AddProperty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_AddProperty)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, name, value");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxString	name;
	wxString	value;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

    WXSTRING_INPUT( value, wxString, ST(2) )
;
    try {
      THIS->AddProperty( name, value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_DeleteProperty); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_DeleteProperty)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	bool	RETVAL;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      RETVAL = THIS->DeleteProperty( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__XmlNode_GetType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetType)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNodeType	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetType();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlNode_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlNode_GetContent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetContent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetContent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlNode_GetParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetParent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNode *	RETVAL;
    try {
      RETVAL = THIS->GetParent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlNode" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlNode_GetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetNext)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNode *	RETVAL;
    try {
      RETVAL = THIS->GetNext();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlNode" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlNode_GetChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetChildren)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNode *	RETVAL;
    try {
      RETVAL = THIS->GetChildren();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlNode" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_269e5187_067782
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_Wx__XmlNode_GetAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetAttributes)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlAttribute *	RETVAL;
    try {
      RETVAL = THIS->GetAttributes();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlAttribute" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#else
#define XSpp_269e5187_065622
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_Wx__XmlNode_GetProperties); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetProperties)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlProperty *	RETVAL;
    try {
      RETVAL = THIS->GetProperties();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlProperty" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif
#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_269e5187_089425
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_Wx__XmlNode_HasAttribute); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_HasAttribute)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, propName");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	bool	RETVAL;
	wxString	propName;

    WXSTRING_INPUT( propName, wxString, ST(1) )
;
    try {
      RETVAL = THIS->HasAttribute( propName );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSpp_269e5187_009212
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_Wx__XmlNode_HasProp); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_HasProp)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, propName");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	bool	RETVAL;
	wxString	propName;

    WXSTRING_INPUT( propName, wxString, ST(1) )
;
    try {
      RETVAL = THIS->HasProp( propName );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__XmlNode_SetType); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_SetType)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, type");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNodeType	type = (wxXmlNodeType)SvIV(ST(1))
;
    try {
      THIS->SetType( type );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_SetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_SetName)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, name");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxString	name;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->SetName( name );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_SetContent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_SetContent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, con");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxString	con;

    WXSTRING_INPUT( con, wxString, ST(1) )
;
    try {
      THIS->SetContent( con );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_SetParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_SetParent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, parent");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNode*    parent = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
    try {
      THIS->SetParent( parent );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_SetNext); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_SetNext)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, next");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNode*    next = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
    try {
      THIS->SetNext( next );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlNode_SetChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_SetChildren)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, child");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlNode*    child = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
    try {
      THIS->SetChildren( child );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSpp_269e5187_070037
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_Wx__XmlNode_SetAttributes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_SetAttributes)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, prop");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlAttribute*    prop = (wxXmlAttribute *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlAttribute" )
;
    try {
      THIS->SetAttributes( prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#else
#define XSpp_269e5187_011411
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_Wx__XmlNode_SetProperties); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_SetProperties)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, prop");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	wxXmlProperty*    prop = (wxXmlProperty *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlProperty" )
;
    try {
      THIS->SetProperties( prop );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}

#endif

XS_EUPXS(XS_Wx__XmlNode_Destroy); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_Destroy)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
    delete THIS;
    }
    XSRETURN_EMPTY;
}

#if WXPERL_W_VERSION_GE( 2, 9, 0 )
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_Wx__XmlNode_GetAttribute); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetAttribute)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, name, value = &PL_sv_undef");
    {
	wxString	name;
	SV*	value;
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	SV *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	if (items < 3)
	    value = &PL_sv_undef;
	else {
	    value = ST(2)
;
	}
    wxString tmp;
    bool ok = THIS->GetAttribute(name, &tmp);
    if( ok )
        RETVAL = wxPli_wxString_2_sv( aTHX_ tmp, NEWSV(0, 0) );
    else
        RETVAL = SvREFCNT_inc( value );
	RETVAL = sv_2mortal(RETVAL);
	ST(0) = RETVAL;
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_Wx__XmlNode_GetPropVal); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlNode_GetPropVal)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, name, value = &PL_sv_undef");
    {
	wxString	name;
	SV*	value;
	wxXmlNode *    THIS = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::XmlNode" )
;
	SV *	RETVAL;

    WXSTRING_INPUT( name, wxString, ST(1) )
;

	if (items < 3)
	    value = &PL_sv_undef;
	else {
	    value = ST(2)
;
	}
    wxString tmp;
    bool ok = THIS->GetPropVal(name, &tmp);
    if( ok )
        RETVAL = wxPli_wxString_2_sv( aTHX_ tmp, NEWSV(0, 0) );
    else
        RETVAL = SvREFCNT_inc( value );
	RETVAL = sv_2mortal(RETVAL);
	ST(0) = RETVAL;
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'XRC.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/XmlNode.xsp' */


/* INCLUDE_COMMAND:  Including output of '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/XmlResourceHandler.xsp' from 'XRC.xs' */

#include <exception>

#undef  xsp_constructor_class
#define xsp_constructor_class(c) (c)
#include "wx/window.h"
#include "xspp/reshnd.h"

XS_EUPXS(XS_Wx__PlXmlResourceHandler_new); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__PlXmlResourceHandler_new)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "CLASS");
    {
	char *	CLASS = (char *)SvPV_nolen(ST(0))
;
	wxPlXmlResourceHandler *	RETVAL;
    RETVAL = new wxPlXmlResourceHandler( CLASS );
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetResource); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetResource)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxXmlResource *	RETVAL;
    try {
      RETVAL = THIS->GetResource();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlResource" );
    wxPli_thread_sv_register( aTHX_ "Wx::XmlResource", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetNode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetNode)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxXmlNode *	RETVAL;
    try {
      RETVAL = THIS->GetNode();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlNode" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetClass); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetClass)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetClass();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetParent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetParent)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxObject *	RETVAL;
    try {
      RETVAL = THIS->GetParent();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetInstance); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetInstance)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxObject *	RETVAL;
    try {
      RETVAL = THIS->GetInstance();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetParentAsWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetParentAsWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetParentAsWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if WXPERL_W_VERSION_LE( 2, 5, 2 )
#define XSpp_5713f9eb_012226
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_Wx__XmlResourceHandler_GetInstanceAsWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetInstanceAsWindow)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxWindow *	RETVAL;
    try {
      RETVAL = THIS->GetInstanceAsWindow();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_Wx__XmlResourceHandler_IsOfClass); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_IsOfClass)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, node, className");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	bool	RETVAL;
	wxXmlNode*    node = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
	wxString	className;

    WXSTRING_INPUT( className, wxString, ST(2) )
;
    try {
      RETVAL = THIS->IsOfClass( node, className );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetNodeContent); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetNodeContent)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, node");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxString	RETVAL;
	wxXmlNode*    node = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
    try {
      RETVAL = THIS->GetNodeContent( node );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_HasParam); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_HasParam)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, param");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	bool	RETVAL;
	wxString	param;

    WXSTRING_INPUT( param, wxString, ST(1) )
;
    try {
      RETVAL = THIS->HasParam( param );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetParamNode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetParamNode)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, param");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxXmlNode *	RETVAL;
	wxString	param;

    WXSTRING_INPUT( param, wxString, ST(1) )
;
    try {
      RETVAL = THIS->GetParamNode( param );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::XmlNode" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetParamValue); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetParamValue)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, param");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxString	RETVAL;
	wxString	param;

    WXSTRING_INPUT( param, wxString, ST(1) )
;
    try {
      RETVAL = THIS->GetParamValue( param );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_AddStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_AddStyle)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "THIS, name, value");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxString	name;
	int	value = (int)SvIV(ST(2))
;

    WXSTRING_INPUT( name, wxString, ST(1) )
;
    try {
      THIS->AddStyle( name, value );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResourceHandler_AddWindowStyles); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_AddWindowStyles)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
    try {
      THIS->AddWindowStyles();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetStyle); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetStyle)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "THIS, param= wxT(\"style\"), defaults= 0");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	int	RETVAL;
	dXSTARG;
	wxString	param;
	int	defaults;

	if (items < 2)
	    param = wxT("style");
	else {
    WXSTRING_INPUT( param, wxString, ST(1) )
;
	}

	if (items < 3)
	    defaults = 0;
	else {
	    defaults = (int)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->GetStyle( param, defaults );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetText); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetText)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, param, translate= true");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxString	RETVAL;
	wxString	param;
	bool	translate;

    WXSTRING_INPUT( param, wxString, ST(1) )
;

	if (items < 3)
	    translate = true;
	else {
	    translate = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->GetText( param, translate );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetID); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetID)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	int	RETVAL;
	dXSTARG;
    try {
      RETVAL = THIS->GetID();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetName); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetName)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "THIS");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxString	RETVAL;
    try {
      RETVAL = THIS->GetName();
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    WXSTRING_OUTPUT( RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetBool); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetBool)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, param, defaultv= false");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	bool	RETVAL;
	wxString	param;
	bool	defaultv;

    WXSTRING_INPUT( param, wxString, ST(1) )
;

	if (items < 3)
	    defaultv = false;
	else {
	    defaultv = (bool)SvTRUE(ST(2))
;
	}
    try {
      RETVAL = THIS->GetBool( param, defaultv );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetLong); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetLong)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, param, defaultv= 0");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	long	RETVAL;
	dXSTARG;
	wxString	param;
	long	defaultv;

    WXSTRING_INPUT( param, wxString, ST(1) )
;

	if (items < 3)
	    defaultv = 0;
	else {
	    defaultv = (long)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->GetLong( param, defaultv );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetColour); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetColour)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, param");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxColour *	RETVAL;
	wxString	param;

    WXSTRING_INPUT( param, wxString, ST(1) )
;
    try {
      RETVAL = new wxColour( THIS->GetColour( param ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, RETVAL, "Wx::Colour" );
    wxPli_thread_sv_register( aTHX_ "Wx::Colour", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetSize); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetSize)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, param= wxT(\"size\")");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxSize	RETVAL;
	wxString	param;

	if (items < 2)
	    param = wxT("size");
	else {
    WXSTRING_INPUT( param, wxString, ST(1) )
;
	}
    try {
      RETVAL = THIS->GetSize( param );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxSize(RETVAL), "Wx::Size" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetPosition); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetPosition)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, param= wxT(\"pos\")");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxPoint	RETVAL;
	wxString	param;

	if (items < 2)
	    param = wxT("pos");
	else {
    WXSTRING_INPUT( param, wxString, ST(1) )
;
	}
    try {
      RETVAL = THIS->GetPosition( param );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_non_object_2_sv( aTHX_ RETVALSV, new wxPoint(RETVAL), "Wx::Point" );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetDimension); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetDimension)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, param, defaultv= 0");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxCoord	RETVAL;
	dXSTARG;
	wxString	param;
	wxCoord	defaultv;

    WXSTRING_INPUT( param, wxString, ST(1) )
;

	if (items < 3)
	    defaultv = 0;
	else {
	    defaultv = (wxCoord)SvIV(ST(2))
;
	}
    try {
      RETVAL = THIS->GetDimension( param, defaultv );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetBitmap); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetBitmap)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "THIS, param= wxT(\"bitmap\"), defaultArtClient= wxART_OTHER, size= wxDefaultSize");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxBitmap *	RETVAL;
	wxString	param;
	wxString	defaultArtClient;
	wxSize	size;

	if (items < 2)
	    param = wxT("bitmap");
	else {
    WXSTRING_INPUT( param, wxString, ST(1) )
;
	}

	if (items < 3)
	    defaultArtClient = wxART_OTHER;
	else {
    WXSTRING_INPUT( defaultArtClient, wxString, ST(2) )
;
	}

	if (items < 4)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(3) )
;
	}
    try {
      RETVAL = new wxBitmap( THIS->GetBitmap( param, defaultArtClient, size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Bitmap", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetIcon); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetIcon)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 4)
       croak_xs_usage(cv,  "THIS, param= wxT(\"icon\"), defaultArtClient= wxART_OTHER, size= wxDefaultSize");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxIcon *	RETVAL;
	wxString	param;
	wxString	defaultArtClient;
	wxSize	size;

	if (items < 2)
	    param = wxT("icon");
	else {
    WXSTRING_INPUT( param, wxString, ST(1) )
;
	}

	if (items < 3)
	    defaultArtClient = wxART_OTHER;
	else {
    WXSTRING_INPUT( defaultArtClient, wxString, ST(2) )
;
	}

	if (items < 4)
	    size = wxDefaultSize;
	else {
    size = wxPli_sv_2_wxsize( aTHX_ ST(3) )
;
	}
    try {
      RETVAL = new wxIcon( THIS->GetIcon( param, defaultArtClient, size ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Icon", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_GetFont); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_GetFont)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "THIS, param= wxT(\"font\")");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxFont *	RETVAL;
	wxString	param;

	if (items < 2)
	    param = wxT("font");
	else {
    WXSTRING_INPUT( param, wxString, ST(1) )
;
	}
    try {
      RETVAL = new wxFont( THIS->GetFont( param ) );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
    wxPli_thread_sv_register( aTHX_ "Wx::Font", RETVAL, RETVALSV );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_Wx__XmlResourceHandler_SetupWindow); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_SetupWindow)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "THIS, wnd");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxWindow*    wnd = (wxWindow *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Window" )
;
    try {
      THIS->SetupWindow( wnd );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResourceHandler_CreateChildren); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_CreateChildren)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, parent, this_hnd_only= false");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxObject*    parent = (wxObject *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Object" )
;
	bool	this_hnd_only;

	if (items < 3)
	    this_hnd_only = false;
	else {
	    this_hnd_only = (bool)SvTRUE(ST(2))
;
	}
    try {
      THIS->CreateChildren( parent, this_hnd_only );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResourceHandler_CreateChildrenPrivately); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_CreateChildrenPrivately)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "THIS, parent, rootnode= NULL");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxObject*    parent = (wxObject *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::Object" )
;
	wxXmlNode*	rootnode;

	if (items < 3)
	    rootnode = NULL;
	else {
    rootnode = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::XmlNode" )
;
	}
    try {
      THIS->CreateChildrenPrivately( parent, rootnode );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx__XmlResourceHandler_CreateResFromNode); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx__XmlResourceHandler_CreateResFromNode)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "THIS, node, parent, instance= NULL");
    {
	wxPlXmlResourceHandler *    THIS = (wxPlXmlResourceHandler *) wxPli_sv_2_object( aTHX_ ST(0), "Wx::PlXmlResourceHandler" )
;
	wxObject *	RETVAL;
	wxXmlNode*    node = (wxXmlNode *) wxPli_sv_2_object( aTHX_ ST(1), "Wx::XmlNode" )
;
	wxObject*    parent = (wxObject *) wxPli_sv_2_object( aTHX_ ST(2), "Wx::Object" )
;
	wxObject*	instance;

	if (items < 4)
	    instance = NULL;
	else {
    instance = (wxObject *) wxPli_sv_2_object( aTHX_ ST(3), "Wx::Object" )
;
	}
    try {
      RETVAL = THIS->CreateResFromNode( node, parent, instance );
    }
    catch (std::exception& e) {
      croak("Caught C++ exception of type or derived from 'std::exception': %s", e.what());
    }
    catch (...) {
      croak("Caught C++ exception of unknown type");
    }
	{
	    SV * RETVALSV;
	    RETVALSV = sv_newmortal();
    wxPli_object_2_sv( aTHX_ RETVALSV, RETVAL );
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


/* INCLUDE: Returning to 'XRC.xs' from '/usr/bin/perl -MExtUtils::XSpp::Cmd -e xspp -- -t ../../typemap.xsp XS/XmlResourceHandler.xsp' */


XS_EUPXS(XS_Wx_XmlInitXmlModule); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_XmlInitXmlModule)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
    // nothing here
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_Wx_XmlInitResourceModule); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_Wx_XmlInitResourceModule)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {

	wxXmlInitResourceModule();
    }
    XSRETURN_EMPTY;
}

#include "cpp/overload.h"
#include "cpp/ovl_const.cpp"
#if defined(__WXMSW__)
#undef XS
#define XS( name ) WXXS( name )
#endif
#ifdef __cplusplus
extern "C"
#endif
XS_EXTERNAL(boot_Wx__XRC); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_Wx__XRC)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

#if XSubPPtmpAAAA
        newXS_deffile("Wx::XmlResource::new", XS_Wx__XmlResource_new);
#endif
#if XSubPPtmpAAAB
        newXS_deffile("Wx::XmlResource::new", XS_Wx__XmlResource_new);
#endif
        newXS_deffile("Wx::XmlResource::CLONE", XS_Wx__XmlResource_CLONE);
        newXS_deffile("Wx::XmlResource::DESTROY", XS_Wx__XmlResource_DESTROY);
        newXS_deffile("Wx::XmlResource::Load", XS_Wx__XmlResource_Load);
#if XSubPPtmpAAAC
        newXS_deffile("Wx::XmlResource::Unload", XS_Wx__XmlResource_Unload);
#endif
        newXS_deffile("Wx::XmlResource::InitAllHandlers", XS_Wx__XmlResource_InitAllHandlers);
        newXS_deffile("Wx::XmlResource::AddHandler", XS_Wx__XmlResource_AddHandler);
        newXS_deffile("Wx::XmlResource::ClearHandlers", XS_Wx__XmlResource_ClearHandlers);
        newXS_deffile("Wx::XmlResource::LoadMenu", XS_Wx__XmlResource_LoadMenu);
        newXS_deffile("Wx::XmlResource::LoadMenuBar", XS_Wx__XmlResource_LoadMenuBar);
        newXS_deffile("Wx::XmlResource::LoadMenuBarOnParent", XS_Wx__XmlResource_LoadMenuBarOnParent);
        newXS_deffile("Wx::XmlResource::LoadToolBar", XS_Wx__XmlResource_LoadToolBar);
        newXS_deffile("Wx::XmlResource::LoadDialog", XS_Wx__XmlResource_LoadDialog);
        newXS_deffile("Wx::XmlResource::LoadOnDialog", XS_Wx__XmlResource_LoadOnDialog);
        newXS_deffile("Wx::XmlResource::LoadPanel", XS_Wx__XmlResource_LoadPanel);
        newXS_deffile("Wx::XmlResource::LoadOnPanel", XS_Wx__XmlResource_LoadOnPanel);
        newXS_deffile("Wx::XmlResource::LoadFrame", XS_Wx__XmlResource_LoadFrame);
        newXS_deffile("Wx::XmlResource::LoadFrame2", XS_Wx__XmlResource_LoadFrame2);
        newXS_deffile("Wx::XmlResource::LoadOnFrame", XS_Wx__XmlResource_LoadOnFrame);
        newXS_deffile("Wx::XmlResource::LoadBitmap", XS_Wx__XmlResource_LoadBitmap);
        newXS_deffile("Wx::XmlResource::LoadIcon", XS_Wx__XmlResource_LoadIcon);
        newXS_deffile("Wx::XmlResource::AttachUnknownControl", XS_Wx__XmlResource_AttachUnknownControl);
        newXS_deffile("Wx::XmlResource::GetFlags", XS_Wx__XmlResource_GetFlags);
        newXS_deffile("Wx::XmlResource::SetFlags", XS_Wx__XmlResource_SetFlags);
#if XSubPPtmpAAAD
        newXS_deffile("Wx::XmlResource::GetXRCID", XS_Wx__XmlResource_GetXRCID);
#endif
#if XSubPPtmpAAAE
        newXS_deffile("Wx::XmlResource::GetXRCID", XS_Wx__XmlResource_GetXRCID);
#endif
        newXS_deffile("Wx::XmlResource::GetVersion", XS_Wx__XmlResource_GetVersion);
        newXS_deffile("Wx::XmlResource::CompareVersion", XS_Wx__XmlResource_CompareVersion);
        newXS_deffile("Wx::XmlResource::AddSubclassFactory", XS_Wx__XmlResource_AddSubclassFactory);
#if XSubPPtmpAAAF
        newXS_deffile("Wx::XmlResource::GetDomain", XS_Wx__XmlResource_GetDomain);
        newXS_deffile("Wx::XmlResource::SetDomain", XS_Wx__XmlResource_SetDomain);
#endif
        newXS_deffile("Wx::XmlSubclassFactory::new", XS_Wx__XmlSubclassFactory_new);
        newXS_deffile("Wx::XmlDocument::IsOk", XS_Wx__XmlDocument_IsOk);
        newXS_deffile("Wx::XmlDocument::GetRoot", XS_Wx__XmlDocument_GetRoot);
        newXS_deffile("Wx::XmlDocument::GetVersion", XS_Wx__XmlDocument_GetVersion);
        newXS_deffile("Wx::XmlDocument::GetFileEncoding", XS_Wx__XmlDocument_GetFileEncoding);
        newXS_deffile("Wx::XmlDocument::SetRoot", XS_Wx__XmlDocument_SetRoot);
        newXS_deffile("Wx::XmlDocument::SetVersion", XS_Wx__XmlDocument_SetVersion);
        newXS_deffile("Wx::XmlDocument::SetFileEncoding", XS_Wx__XmlDocument_SetFileEncoding);
#if XSubPPtmpAAAG
        newXS_deffile("Wx::XmlDocument::GetEncoding", XS_Wx__XmlDocument_GetEncoding);
        newXS_deffile("Wx::XmlDocument::SetEncoding", XS_Wx__XmlDocument_SetEncoding);
#endif
#if XSubPPtmpAAAH
        newXS_deffile("Wx::XmlAttribute::new", XS_Wx__XmlAttribute_new);
        newXS_deffile("Wx::XmlAttribute::GetName", XS_Wx__XmlAttribute_GetName);
        newXS_deffile("Wx::XmlAttribute::GetValue", XS_Wx__XmlAttribute_GetValue);
        newXS_deffile("Wx::XmlAttribute::GetNext", XS_Wx__XmlAttribute_GetNext);
        newXS_deffile("Wx::XmlAttribute::SetName", XS_Wx__XmlAttribute_SetName);
        newXS_deffile("Wx::XmlAttribute::SetValue", XS_Wx__XmlAttribute_SetValue);
        newXS_deffile("Wx::XmlAttribute::SetNext", XS_Wx__XmlAttribute_SetNext);
        newXS_deffile("Wx::XmlAttribute::Destroy", XS_Wx__XmlAttribute_Destroy);
#endif
#if XSubPPtmpAAAI
        newXS_deffile("Wx::XmlProperty::new", XS_Wx__XmlProperty_new);
        newXS_deffile("Wx::XmlProperty::GetName", XS_Wx__XmlProperty_GetName);
        newXS_deffile("Wx::XmlProperty::GetValue", XS_Wx__XmlProperty_GetValue);
        newXS_deffile("Wx::XmlProperty::GetNext", XS_Wx__XmlProperty_GetNext);
        newXS_deffile("Wx::XmlProperty::SetName", XS_Wx__XmlProperty_SetName);
        newXS_deffile("Wx::XmlProperty::SetValue", XS_Wx__XmlProperty_SetValue);
        newXS_deffile("Wx::XmlProperty::SetNext", XS_Wx__XmlProperty_SetNext);
        newXS_deffile("Wx::XmlProperty::Destroy", XS_Wx__XmlProperty_Destroy);
#endif
#if XSubPPtmpAAAJ
        newXS_deffile("Wx::XmlNode::new", XS_Wx__XmlNode_new);
#endif
#if XSubPPtmpAAAK
        newXS_deffile("Wx::XmlNode::new", XS_Wx__XmlNode_new);
#endif
        newXS_deffile("Wx::XmlNode::AddChild", XS_Wx__XmlNode_AddChild);
        newXS_deffile("Wx::XmlNode::InsertChild", XS_Wx__XmlNode_InsertChild);
        newXS_deffile("Wx::XmlNode::RemoveChild", XS_Wx__XmlNode_RemoveChild);
#if XSubPPtmpAAAL
        newXS_deffile("Wx::XmlNode::AddAttribute", XS_Wx__XmlNode_AddAttribute);
        newXS_deffile("Wx::XmlNode::DeleteAttribute", XS_Wx__XmlNode_DeleteAttribute);
#endif
#if XSubPPtmpAAAM
        newXS_deffile("Wx::XmlNode::AddProperty", XS_Wx__XmlNode_AddProperty);
        newXS_deffile("Wx::XmlNode::DeleteProperty", XS_Wx__XmlNode_DeleteProperty);
#endif
        newXS_deffile("Wx::XmlNode::GetType", XS_Wx__XmlNode_GetType);
        newXS_deffile("Wx::XmlNode::GetName", XS_Wx__XmlNode_GetName);
        newXS_deffile("Wx::XmlNode::GetContent", XS_Wx__XmlNode_GetContent);
        newXS_deffile("Wx::XmlNode::GetParent", XS_Wx__XmlNode_GetParent);
        newXS_deffile("Wx::XmlNode::GetNext", XS_Wx__XmlNode_GetNext);
        newXS_deffile("Wx::XmlNode::GetChildren", XS_Wx__XmlNode_GetChildren);
#if XSubPPtmpAAAN
        newXS_deffile("Wx::XmlNode::GetAttributes", XS_Wx__XmlNode_GetAttributes);
#endif
#if XSubPPtmpAAAO
        newXS_deffile("Wx::XmlNode::GetProperties", XS_Wx__XmlNode_GetProperties);
#endif
#if XSubPPtmpAAAP
        newXS_deffile("Wx::XmlNode::HasAttribute", XS_Wx__XmlNode_HasAttribute);
#endif
#if XSubPPtmpAAAQ
        newXS_deffile("Wx::XmlNode::HasProp", XS_Wx__XmlNode_HasProp);
#endif
        newXS_deffile("Wx::XmlNode::SetType", XS_Wx__XmlNode_SetType);
        newXS_deffile("Wx::XmlNode::SetName", XS_Wx__XmlNode_SetName);
        newXS_deffile("Wx::XmlNode::SetContent", XS_Wx__XmlNode_SetContent);
        newXS_deffile("Wx::XmlNode::SetParent", XS_Wx__XmlNode_SetParent);
        newXS_deffile("Wx::XmlNode::SetNext", XS_Wx__XmlNode_SetNext);
        newXS_deffile("Wx::XmlNode::SetChildren", XS_Wx__XmlNode_SetChildren);
#if XSubPPtmpAAAR
        newXS_deffile("Wx::XmlNode::SetAttributes", XS_Wx__XmlNode_SetAttributes);
#endif
#if XSubPPtmpAAAS
        newXS_deffile("Wx::XmlNode::SetProperties", XS_Wx__XmlNode_SetProperties);
#endif
        newXS_deffile("Wx::XmlNode::Destroy", XS_Wx__XmlNode_Destroy);
#if XSubPPtmpAAAT
        newXS_deffile("Wx::XmlNode::GetAttribute", XS_Wx__XmlNode_GetAttribute);
#endif
#if XSubPPtmpAAAU
        newXS_deffile("Wx::XmlNode::GetPropVal", XS_Wx__XmlNode_GetPropVal);
#endif
        newXS_deffile("Wx::PlXmlResourceHandler::new", XS_Wx__PlXmlResourceHandler_new);
        newXS_deffile("Wx::XmlResourceHandler::GetResource", XS_Wx__XmlResourceHandler_GetResource);
        newXS_deffile("Wx::XmlResourceHandler::GetNode", XS_Wx__XmlResourceHandler_GetNode);
        newXS_deffile("Wx::XmlResourceHandler::GetClass", XS_Wx__XmlResourceHandler_GetClass);
        newXS_deffile("Wx::XmlResourceHandler::GetParent", XS_Wx__XmlResourceHandler_GetParent);
        newXS_deffile("Wx::XmlResourceHandler::GetInstance", XS_Wx__XmlResourceHandler_GetInstance);
        newXS_deffile("Wx::XmlResourceHandler::GetParentAsWindow", XS_Wx__XmlResourceHandler_GetParentAsWindow);
#if XSubPPtmpAAAV
        newXS_deffile("Wx::XmlResourceHandler::GetInstanceAsWindow", XS_Wx__XmlResourceHandler_GetInstanceAsWindow);
#endif
        newXS_deffile("Wx::XmlResourceHandler::IsOfClass", XS_Wx__XmlResourceHandler_IsOfClass);
        newXS_deffile("Wx::XmlResourceHandler::GetNodeContent", XS_Wx__XmlResourceHandler_GetNodeContent);
        newXS_deffile("Wx::XmlResourceHandler::HasParam", XS_Wx__XmlResourceHandler_HasParam);
        newXS_deffile("Wx::XmlResourceHandler::GetParamNode", XS_Wx__XmlResourceHandler_GetParamNode);
        newXS_deffile("Wx::XmlResourceHandler::GetParamValue", XS_Wx__XmlResourceHandler_GetParamValue);
        newXS_deffile("Wx::XmlResourceHandler::AddStyle", XS_Wx__XmlResourceHandler_AddStyle);
        newXS_deffile("Wx::XmlResourceHandler::AddWindowStyles", XS_Wx__XmlResourceHandler_AddWindowStyles);
        newXS_deffile("Wx::XmlResourceHandler::GetStyle", XS_Wx__XmlResourceHandler_GetStyle);
        newXS_deffile("Wx::XmlResourceHandler::GetText", XS_Wx__XmlResourceHandler_GetText);
        newXS_deffile("Wx::XmlResourceHandler::GetID", XS_Wx__XmlResourceHandler_GetID);
        newXS_deffile("Wx::XmlResourceHandler::GetName", XS_Wx__XmlResourceHandler_GetName);
        newXS_deffile("Wx::XmlResourceHandler::GetBool", XS_Wx__XmlResourceHandler_GetBool);
        newXS_deffile("Wx::XmlResourceHandler::GetLong", XS_Wx__XmlResourceHandler_GetLong);
        newXS_deffile("Wx::XmlResourceHandler::GetColour", XS_Wx__XmlResourceHandler_GetColour);
        newXS_deffile("Wx::XmlResourceHandler::GetSize", XS_Wx__XmlResourceHandler_GetSize);
        newXS_deffile("Wx::XmlResourceHandler::GetPosition", XS_Wx__XmlResourceHandler_GetPosition);
        newXS_deffile("Wx::XmlResourceHandler::GetDimension", XS_Wx__XmlResourceHandler_GetDimension);
        newXS_deffile("Wx::XmlResourceHandler::GetBitmap", XS_Wx__XmlResourceHandler_GetBitmap);
        newXS_deffile("Wx::XmlResourceHandler::GetIcon", XS_Wx__XmlResourceHandler_GetIcon);
        newXS_deffile("Wx::XmlResourceHandler::GetFont", XS_Wx__XmlResourceHandler_GetFont);
        newXS_deffile("Wx::XmlResourceHandler::SetupWindow", XS_Wx__XmlResourceHandler_SetupWindow);
        newXS_deffile("Wx::XmlResourceHandler::CreateChildren", XS_Wx__XmlResourceHandler_CreateChildren);
        newXS_deffile("Wx::XmlResourceHandler::CreateChildrenPrivately", XS_Wx__XmlResourceHandler_CreateChildrenPrivately);
        newXS_deffile("Wx::XmlResourceHandler::CreateResFromNode", XS_Wx__XmlResourceHandler_CreateResFromNode);
        newXS_deffile("Wx::XmlInitXmlModule", XS_Wx_XmlInitXmlModule);
        newXS_deffile("Wx::XmlInitResourceModule", XS_Wx_XmlInitResourceModule);

    /* Initialisation Section */

  INIT_PLI_HELPERS( wx_pli_helpers );

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#if XSubPPtmpAAAL
#endif
#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#endif
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#if XSubPPtmpAAAS
#endif
#if XSubPPtmpAAAT
#endif
#if XSubPPtmpAAAU
#endif
#if XSubPPtmpAAAV
#endif

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

